@@ -125,44 +125,45 @@ class GConfSource (userprofile.ProfileSource):
 
         self.storage              = storage
         self.home_dir             = util.get_home_dir ()
-        self.client               = None
+        self.gconf_client         = None
         self.notify_id            = 0
         self.defaults_client      = None
         self.mandatory_client     = None
         self.mandatory_alt_client = None
         self.enforce_mandatory    = True
+        self.SORTPRIORITY         = 10
 
     def get_path_description (self, path):
-        if path == ".gconf.xml.defaults":
+        if path == GCONF_DEFAULTS_SOURCE:
             return _("Default GConf settings")
-        elif path == ".gconf.xml.mandatory":
+        elif path == GCONF_MANDATORY_SOURCE:
             return _("Mandatory GConf settings")
         else:
             return path
 
     def get_committing_client_and_address (self, mandatory):
-        """Get a GConfClient using either .gconf.xml.defaults or
-        .gconf.xml.mandatory (in the temporary profile location)
+        """Get a GConfClient using either GCONF_DEFAULTS_SOURCE or
+        GCONF_MANDATORY_SOURCE (in the temporary profile location)
         as its source.
 
         mandatory: whether to get the mandatory or defaults source
         """
         if not mandatory:
             if not self.defaults_client:
-                (client, address) = get_client_and_address_for_path (os.path.join (self.home_dir, ".gconf.xml.defaults"))
+                (client, address) = get_client_and_address_for_path (os.path.join (self.home_dir, GCONF_DEFAULTS_SOURCE))
                 self.defaults_client = client
                 self.defaults_address = address
             return (self.defaults_client, self.defaults_address)
         else:
             if self.enforce_mandatory:
                 if not self.mandatory_client:
-                    (client, address) = get_client_and_address_for_path (os.path.join (self.home_dir, ".gconf.xml.mandatory"))
+                    (client, address) = get_client_and_address_for_path (os.path.join (self.home_dir, GCONF_MANDATORY_SOURCE))
                     self.mandatory_client = client
                     self.mandatory_address = address
                 return (self.mandatory_client, self.mandatory_address)
             else:
                 if not self.mandatory_alt_client:
-                    (client, address) = get_client_and_address_for_path (os.path.join (self.home_dir, ".gconf.xml.mandatory-alt"))
+                    (client, address) = get_client_and_address_for_path (os.path.join (self.home_dir, GCONF_MANDATORY_ALT_SOURCE))
                     self.mandatory_alt_client = client
                     self.mandatory_alt_address = address
                 return (self.mandatory_alt_client, self.mandatory_alt_address)
@@ -198,7 +199,7 @@ class GConfSource (userprofile.ProfileSource):
             return
         
         def handle_notify (client, cnx_id, entry, self):
-            dprint ("Got GConf notification on '%s'", entry.key)
+            dprint ("Got GConf notification on '%s', value='%s', default=%s", entry.key, entry.value, entry.get_is_default ())
             
             for ignore_pattern in GCONF_KEYS_TO_IGNORE:
                 if fnmatch.fnmatchcase (entry.key, ignore_pattern):
@@ -213,19 +214,19 @@ class GConfSource (userprofile.ProfileSource):
             self.emit_change (GConfChange (self, entry.key, value))
 
         # Only monitor for changes in the user settings database
-        (self.client, address) = get_client_and_address_for_path (os.path.join (self.home_dir, ".gconf"))
-        self.client.add_dir ("/", gconf.CLIENT_PRELOAD_RECURSIVE)
-        self.notify_id = self.client.notify_add ("/", handle_notify, self)
+        (self.gconf_client, address) = get_client_and_address_for_path (os.path.join (self.home_dir, ".gconf"))
+        self.gconf_client.add_dir ("/", gconf.CLIENT_PRELOAD_RECURSIVE)
+        self.notify_id = self.gconf_client.notify_add ("/", handle_notify, self)
 
     def stop_monitoring (self):
         """Stop monitoring for GConf changes."""
         if self.notify_id == 0:
             return
 
-        self.client.notify_remove (self.notify_id)
+        self.gconf_client.notify_remove (self.notify_id)
         self.notify_id = 0
-        self.client.remove_dir ("/")
-        self.client = None
+        self.gconf_client.remove_dir ("/")
+        self.gconf_client = None
 
     def sync_changes (self):
         """Ensure that all committed changes are saved to disk."""
@@ -243,15 +244,15 @@ class GConfSource (userprofile.ProfileSource):
         time.sleep (2)
         
 
-        if os.path.exists (os.path.join (self.home_dir, ".gconf.xml.defaults")):
-            self.storage.add (".gconf.xml.defaults", self.home_dir, self.name)
+        if os.path.exists (os.path.join (self.home_dir, GCONF_DEFAULTS_SOURCE)):
+            self.storage.add (GCONF_DEFAULTS_SOURCE, self.home_dir, self.name)
 
         if self.enforce_mandatory:
-            mandatory_src = ".gconf.xml.mandatory"
+            mandatory_src = GCONF_MANDATORY_SOURCE
         else:
-            mandatory_src = ".gconf.xml.mandatory-alt"
+            mandatory_src = GCONF_MANDATORY_ALT_SOURCE
         if os.path.exists (os.path.join (self.home_dir, mandatory_src)):
-            self.storage.add (".gconf.xml.mandatory", self.home_dir, self.name, src_path = mandatory_src)
+            self.storage.add (GCONF_MANDATORY_SOURCE, self.home_dir, self.name, src_path = mandatory_src)
 
     def set_enforce_mandatory (self, enforce):
         if enforce == self.enforce_mandatory:
@@ -304,18 +305,18 @@ class GConfSource (userprofile.ProfileSource):
 
         storage_contents = self.storage.list (self.name)
 
-        if ("GConf", ".gconf.xml.defaults") in storage_contents:
-            self.storage.extract (".gconf.xml.defaults", self.home_dir, True)
-        default_path = "xml:readonly:" + os.path.join (self.home_dir, ".gconf.xml.defaults");
+        if ("GConf", GCONF_DEFAULTS_SOURCE) in storage_contents:
+            self.storage.extract (GCONF_DEFAULTS_SOURCE, self.home_dir, True)
+        default_path = "xml:readonly:" + os.path.join (self.home_dir, GCONF_DEFAULTS_SOURCE);
         if is_sabayon_session:
-            default_path = "xml:readonly:" + os.path.join (self.home_dir, ".gconf.xml.mandatory-alt") + "\n" + default_path
+            default_path = "xml:readonly:" + os.path.join (self.home_dir, GCONF_MANDATORY_ALT_SOURCE) + "\n" + default_path
                                                   
-        write_path_file (os.path.join (self.home_dir, ".gconf.path.defaults"), default_path)
+        write_path_file (os.path.join (self.home_dir, GCONF_PATH_DEFAULTS), default_path)
         
-        if ("GConf", ".gconf.xml.mandatory") in storage_contents:
-            self.storage.extract (".gconf.xml.mandatory", self.home_dir, True)
-        write_path_file (os.path.join (self.home_dir, ".gconf.path.mandatory"),
-                         "xml:readonly:" + os.path.join (self.home_dir, ".gconf.xml.mandatory"))
+        if ("GConf", GCONF_MANDATORY_SOURCE) in storage_contents:
+            self.storage.extract (GCONF_MANDATORY_SOURCE, self.home_dir, True)
+        write_path_file (os.path.join (self.home_dir, GCONF_PATH_MANDATORY),
+                         "xml:readonly:" + os.path.join (self.home_dir, GCONF_MANDATORY_SOURCE))
 
         # FIXME: perhaps just kill -HUP it? It would really just be better
         #        if we could guarantee that there wasn't a gconfd already
@@ -324,10 +325,10 @@ class GConfSource (userprofile.ProfileSource):
         subprocess.call (["gconftool-2", "--shutdown"])
 
     def add_gconf_notify (self, key, handler, data):
-        return self.client.notify_add (key, handler, data)
+        return self.gconf_client.notify_add (key, handler, data)
 
     def remove_gconf_notify (self, id):
-        return self.client.notify_remove (id)
+        return self.gconf_client.notify_remove (id)
 
     def get_gconf_key_is_mandatory (self, key):
         (client, address) = self.get_committing_client_and_address (True)
@@ -339,7 +340,7 @@ class GConfSource (userprofile.ProfileSource):
     def set_value (self, key, gconf_value, mandatory):
         change = GConfChange (self, key, gconf_value)
         change.set_mandatory (mandatory)
-        self.client.set (key, gconf_value)
+        self.gconf_client.set (key, gconf_value)
         self.emit_change (change)
 
     def set_gconf_boolean (self, key, value, mandatory):
@@ -390,8 +391,8 @@ def run_unit_tests ():
 
     # Remove any stale path files
     try:
-        os.remove (os.path.join (util.get_home_dir (), ".gconf.path.defaults"))
-        os.remove (os.path.join (util.get_home_dir (), ".gconf.path.mandatory"))
+        os.remove (os.path.join (util.get_home_dir (), GCONF_PATH_DEFAULTS))
+        os.remove (os.path.join (util.get_home_dir (), GCONF_PATH_MANDATORY))
     except:
         pass
 
@@ -401,7 +402,7 @@ def run_unit_tests ():
 
     # Make sure there's no stale keys from a previous run
     # FIXME: gconf_client_recursive_unset() has no wrapping
-    # source.client.recursive_unset ("/tmp/test-gconfprofile")
+    # source.gconf_client.recursive_unset ("/tmp/test-gconfprofile")
     subprocess.call (["gconftool-2", "--recursive-unset", "/tmp/test-gconfprofile"])
     time.sleep (1)
 
@@ -423,17 +424,17 @@ def run_unit_tests ():
         while main_loop.get_context ().pending ():
             main_loop.get_context ().iteration (False)
         
-    source.client.set_bool ("/tmp/test-gconfprofile/t1", True)
+    source.gconf_client.set_bool ("/tmp/test-gconfprofile/t1", True)
     poll (main_loop)
-    source.client.set_bool ("/tmp/test-gconfprofile/t1", False)
+    source.gconf_client.set_bool ("/tmp/test-gconfprofile/t1", False)
     poll (main_loop)
-    source.client.set_bool ("/tmp/test-gconfprofile/t2", True)
+    source.gconf_client.set_bool ("/tmp/test-gconfprofile/t2", True)
     poll (main_loop)
-    source.client.set_int ("/tmp/test-gconfprofile/t3", 3)
+    source.gconf_client.set_int ("/tmp/test-gconfprofile/t3", 3)
     poll (main_loop)
     
     source.stop_monitoring ()
-    source.client = gconf.client_get_default ()
+    source.gconf_client = gconf.client_get_default ()
     
     assert len (changes) == 4
     assert changes[3].key == "/tmp/test-gconfprofile/t3"
@@ -445,28 +446,28 @@ def run_unit_tests ():
     assert changes[1].key == "/tmp/test-gconfprofile/t1"
     assert changes[0].key == "/tmp/test-gconfprofile/t1"
 
-    # source.client.recursive_unset ("/tmp/test-gconfprofile")
+    # source.gconf_client.recursive_unset ("/tmp/test-gconfprofile")
     subprocess.call (["gconftool-2", "--recursive-unset", "/tmp/test-gconfprofile"])
     
     source.sync_changes ()
     source.apply (False)
 
-    assert os.access (os.path.join (util.get_home_dir (), ".gconf.path.defaults"), os.F_OK)
-    assert os.access (os.path.join (util.get_home_dir (), ".gconf.path.mandatory"), os.F_OK)
+    assert os.access (os.path.join (util.get_home_dir (), GCONF_PATH_DEFAULTS), os.F_OK)
+    assert os.access (os.path.join (util.get_home_dir (), GCONF_PATH_MANDATORY), os.F_OK)
 
     # We need to clear the cache because GConfClient doesn't know
     # some new sources have been added to the sources stack so it
     # won't see the value we put in the mandatory source
-    source.client.clear_cache ()
+    source.gconf_client.clear_cache ()
     
-    entry = source.client.get_entry ("/tmp/test-gconfprofile/t3", "", False)
+    entry = source.gconf_client.get_entry ("/tmp/test-gconfprofile/t3", "", False)
     assert entry.value
     assert entry.value.type == gconf.VALUE_INT
     assert entry.value.get_int () == 3
     assert not entry.get_is_default ()
     assert entry.get_is_writable ()
     
-    entry = source.client.get_entry ("/tmp/test-gconfprofile/t2", "", False)
+    entry = source.gconf_client.get_entry ("/tmp/test-gconfprofile/t2", "", False)
     assert entry.value
     assert entry.value.type == gconf.VALUE_BOOL
     assert entry.value.get_bool () == True
@@ -478,8 +479,8 @@ def run_unit_tests ():
     subprocess.call (["gconftool-2", "--shutdown"])
     time.sleep (1)
 
-    os.remove (os.path.join (util.get_home_dir (), ".gconf.path.defaults"))
-    os.remove (os.path.join (util.get_home_dir (), ".gconf.path.mandatory"))
+    os.remove (os.path.join (util.get_home_dir (), GCONF_PATH_DEFAULTS))
+    os.remove (os.path.join (util.get_home_dir (), GCONF_PATH_MANDATORY))
     
     if os.path.exists (profile_path):
         os.remove (profile_path)
